summaryrefslogtreecommitdiff
path: root/framework/source/uielement/progressbarwrapper.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-13 16:59:57 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-14 06:37:16 +0000
commitd191d1f9b684c6229f3651361c92ff39ffb350f1 (patch)
treee670ba0105d974b3a68c17b42366eec1d35ebae4 /framework/source/uielement/progressbarwrapper.cxx
parentba974ccc8c49766542ddd727c95ecc5db1cff198 (diff)
com::sun::star->css in framework
Change-Id: If5a77db83fcbef5ed436f2043ddeb7c515a840dc Reviewed-on: https://gerrit.libreoffice.org/19356 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'framework/source/uielement/progressbarwrapper.cxx')
-rw-r--r--framework/source/uielement/progressbarwrapper.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/uielement/progressbarwrapper.cxx b/framework/source/uielement/progressbarwrapper.cxx
index d753b9e72ec4..20ccae7d434d 100644
--- a/framework/source/uielement/progressbarwrapper.cxx
+++ b/framework/source/uielement/progressbarwrapper.cxx
@@ -34,7 +34,7 @@ using namespace ::com::sun::star;
namespace framework{
ProgressBarWrapper::ProgressBarWrapper() :
-UIElementWrapperBase( ::com::sun::star::ui::UIElementType::PROGRESSBAR )
+UIElementWrapperBase( css::ui::UIElementType::PROGRESSBAR )
, m_bOwnsInstance( false )
, m_nRange( 100 )
, m_nValue( 0 )
@@ -82,7 +82,7 @@ uno::Reference< awt::XWindow > ProgressBarWrapper::getStatusBar() const
return m_xStatusBar;
}
// wrapped methods of ::com::sun::star::task::XStatusIndicator
void ProgressBarWrapper::start( const OUString& Text, ::sal_Int32 Range )
throw (uno::RuntimeException, std::exception)
{
@@ -82,7 +82,7 @@ uno::Reference< awt::XWindow > ProgressBarWrapper::getStatusBar() const
return m_xStatusBar;
}
-// wrapped methods of ::com::sun::star::task::XStatusIndicator
+// wrapped methods of css::task::XStatusIndicator
void ProgressBarWrapper::start( const OUString& Text, ::sal_Int32 Range )
throw (uno::RuntimeException, std::exception)